@@ -19,7 +19,7 @@
 #include <tqimage.h>
 
 #include <kdebug.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 
 #include "kis_abstract_colorspace.h"
 #include "kis_global.h"
@@ -89,7 +89,7 @@ void KisAbstractColorSpace::init()
 {
     // Default pixel buffer for TQColor conversion
     m_qcolordata = new TQ_UINT8[3];
-    Q_CHECK_PTR(m_qcolordata);
+    TQ_CHECK_PTR(m_qcolordata);
 
     if (m_profile == 0) return;
 
@@ -719,7 +719,7 @@ cmsHTRANSFORM KisAbstractColorSpace::createTransform(KisColorSpace * dstColorSpa
                              KisProfile *  dstProfile,
                              TQ_INT32 renderingIntent)
 {
-    KConfig * cfg = KGlobal::config();
+    TDEConfig * cfg = TDEGlobal::config();
     bool bpCompensation = cfg->readBoolEntry("useBlackPointCompensation", false);
 
     int flags = 0;
