@@ -19,7 +19,7 @@
 #ifndef WSBRUSH_PAINTOP_PLUGIN_H_
 #define WSBRUSH_PAINTOP_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 #include "kis_types.h"
 
@@ -31,7 +31,7 @@ class KisView;
 class WSBrushPaintOpPlugin : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     WSBrushPaintOpPlugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~WSBrushPaintOpPlugin();
