@@ -41,12 +41,12 @@
 #include <tqlineedit.h>
 
 #include <knuminput.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 #include <kinstance.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kstandarddirs.h>
-#include <ktempfile.h>
+#include <tdetempfile.h>
 #include <kdebug.h>
 #include <kgenericfactory.h>
 #include <kcombobox.h>
@@ -461,7 +461,7 @@ KisBumpmapConfigWidget::KisBumpmapConfigWidget(KisFilter *, KisPaintDeviceSP dev
 {
     m_page = new WdgBumpmap(this);
     TQHBoxLayout * l = new TQHBoxLayout(this);
-    Q_CHECK_PTR(l);
+    TQ_CHECK_PTR(l);
 
     l->add(m_page);
 
