@@ -24,7 +24,7 @@
 #include <gnumericexport.h>
 #include <kdebug.h>
 #include <kfilterdev.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kgenericfactory.h>
 #include <KoFilterChain.h>
 #include <tqapplication.h>
@@ -997,7 +997,7 @@ KoFilter::ConversionStatus GNUMERICExport::convert( const TQCString& from, const
     addAttributeItem(gnumeric_doc, attributes, "4", "WorkbookView::show_horizontal_scrollbar", ksdoc->showHorizontalScrollBar());
     addAttributeItem(gnumeric_doc, attributes, "4", "WorkbookView::show_vertical_scrollbar", ksdoc->showVerticalScrollBar());
     addAttributeItem(gnumeric_doc, attributes, "4", "WorkbookView::show_notebook_tabs", ksdoc->showTabBar());
-    if (ksdoc->completionMode() == KGlobalSettings::CompletionAuto)
+    if (ksdoc->completionMode() == TDEGlobalSettings::CompletionAuto)
         addAttributeItem(gnumeric_doc, attributes, "4", "WorkbookView::do_auto_completion", "true");
     else
         addAttributeItem(gnumeric_doc, attributes, "4", "WorkbookView::do_auto_completion", "false");
