@@ -61,7 +61,7 @@ public:
 protected:
     virtual void setupTranslations( void )
     {
-        KGlobal::locale()->insertCatalogue( "kofficefilters" );
+        TDEGlobal::locale()->insertCatalogue( "kofficefilters" );
     }
 };
 
