@@ -34,7 +34,7 @@
 #include <kmdcodec.h>
 #include <kfilterdev.h>
 #include <kgenericfactory.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 #include <KoPageLayout.h>
 #include <KoStore.h>
@@ -55,7 +55,7 @@ public:
 protected:
     virtual void setupTranslations( void )
     {
-        KGlobal::locale()->insertCatalogue( "kofficefilters" );
+        TDEGlobal::locale()->insertCatalogue( "kofficefilters" );
     }
 };
 
