@@ -28,7 +28,7 @@
 #include <tqvaluelist.h>
 
 #include <kurl.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 #include <KoPicture.h>
 #include <KoFilterManager.h>
