@@ -26,7 +26,7 @@ using std::cerr;
 #include <KoOasisLoadingContext.h>
 
 #include <kstandarddirs.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <kdebug.h>
 
 #include <tqdom.h>
@@ -724,8 +724,8 @@ void KChartPart::setChartDefaults()
   yAxis = m_params->axisParams( KDChartAxisParams::AxisPosLeft );
 
   // decimal symbol and thousands separator
-  yAxis.setAxisLabelsRadix( KGlobal::locale()->decimalSymbol(),
-			    KGlobal::locale()->thousandsSeparator() );
+  yAxis.setAxisLabelsRadix( TDEGlobal::locale()->decimalSymbol(),
+			    TDEGlobal::locale()->thousandsSeparator() );
 
   m_params->setAxisParams( KDChartAxisParams::AxisPosLeft, yAxis );
 
@@ -760,7 +760,7 @@ void KChartPart::setChartDefaults()
 
 
 
-void KChartPart::loadConfig( KConfig *conf )
+void KChartPart::loadConfig( TDEConfig *conf )
 {
     conf->setGroup("ChartParameters");
 
@@ -871,7 +871,7 @@ void KChartPart::defaultConfig(  )
 }
 
 
-void KChartPart::saveConfig( KConfig *conf )
+void KChartPart::saveConfig( TDEConfig *conf )
 {
     conf->setGroup("ChartParameters");
 
