@@ -127,9 +127,9 @@ void KDFrame::paintEdges( TQPainter& painter, const TQRect& innerRect ) const
             TQPen thePen;
             thePen = section->pen();
             int penWidth = TQMAX(thePen.width(), 1) * TQMAX(section->width(), 1);
-//qDebug("paintEdges: thePen.width() = %i", thePen.width());
-//qDebug("paintEdges: section->width() = %i", section->width());
-//qDebug("paintEdges: penWidth = %i", penWidth);
+//tqDebug("paintEdges: thePen.width() = %i", thePen.width());
+//tqDebug("paintEdges: section->width() = %i", section->width());
+//tqDebug("paintEdges: penWidth = %i", penWidth);
             thePen.setWidth( penWidth );
             painter.setPen( thePen );
             painter.setBrush( TQt::NoBrush );
@@ -262,13 +262,13 @@ void KDFrame::setSimpleFrame( SimpleFrame frame,
     _backPixmap = backPixmap ? *backPixmap : TQPixmap();
     _backPixmapMode = backPixmapMode;
     if( FrameFlat == frame ) {
-        //qDebug("_profileSections.count() before = %i", _profileSections.count());
+        //tqDebug("_profileSections.count() before = %i", _profileSections.count());
         KDFrameProfileSection* newsection =
             new KDFrameProfileSection( KDFrameProfileSection::DirPlain,
                     KDFrameProfileSection::CvtPlain,
                     lineWidth, pen );
         _profileSections.append( newsection );
-        //qDebug( "_profileSections.count() after = %i,    lineWidth = %i",
+        //tqDebug( "_profileSections.count() after = %i,    lineWidth = %i",
         //        _profileSections.count(),
         //        lineWidth );
         _topProfile.append( newsection );
@@ -526,7 +526,7 @@ bool KDFrame::readFrameNode( const TQDomElement& element, KDFrame& frame )
                 ok = ok & KDFrameCorner::readFrameCornerNode( element,
                         tempCornerBR );
             } else {
-                qDebug( "Unknown tag in frame" );
+                tqDebug( "Unknown tag in frame" );
             }
         }
         node = node.nextSibling();
@@ -567,7 +567,7 @@ bool KDFrame::readFrameProfileNode( const TQDomElement& element,
                         section );
                 profile.append( section );
             } else {
-                qDebug( "Unknown tag in double map" );
+                tqDebug( "Unknown tag in double map" );
                 return false;
             }
         }
@@ -600,7 +600,7 @@ bool KDFrame::KDFrameCorner::readFrameCornerNode( const TQDomElement& element,
                 KDFrameProfile profile;
                 ok = ok & readFrameProfileNode( element, profile );
             } else {
-                qDebug( "Unknown tag in frame" );
+                tqDebug( "Unknown tag in frame" );
             }
         }
         node = node.nextSibling();
