@@ -40,7 +40,7 @@ class TQDomElement;
 class TQDomDocument;
 class TQVariant;
 class TQListView;
-class KActionCollection;
+class TDEActionCollection;
 class KTextEdit;
 class KLineEdit;
 class KXMLGUIClient;
@@ -107,7 +107,7 @@ class KFORMEDITOR_EXPORT WidgetInfo
 		 If this name is found when loading a .ui file, the className() will be used instead.
 		 It allows to support both KDE and TQt versions of widget, without duplicating code.
 		 As a rule, className() should always return a class name which is inherited from
-		 alternate class. For example KListView class has alternate TQListView class.
+		 alternate class. For example TDEListView class has alternate TQListView class.
 
 		 \a override parameter overrides class name of a widget,
 		 even if it was implemented in other factory.
@@ -150,13 +150,13 @@ class KFORMEDITOR_EXPORT WidgetInfo
 
 		WidgetInfo* inheritedClass() const { return m_inheritedClass; }
 
-		/*! Sets custom type \a type for property \a propertyName. 
-		 This allows to override default type, especially when custom property 
+		/*! Sets custom type \a type for property \a propertyName.
+		 This allows to override default type, especially when custom property
 		 and custom property editor item has to be used. */
 		void setCustomTypeForProperty(const char *propertyName, int type);
 
 		/*! \return custom type for property \a propertyName. If no specific custom type has been assigned,
-		 KoProperty::Auto is returned. 
+		 KoProperty::Auto is returned.
 		 @see setCustomTypeForProperty() */
 		int customTypeForProperty(const char *propertyName) const;
 
@@ -195,7 +195,7 @@ class KFORMEDITOR_EXPORT WidgetInfo
   You can use createMenuActions() to add custom items in widget's context menu. The previewWidget()
   is called when the Form gets in Preview mode, and you have a last opportunity to remove all editing-related
   stuff (see eg \ref Spring class).\n
-  You can also choose which properties to show in the Property Editor. 
+  You can also choose which properties to show in the Property Editor.
   By default, most all properties are shown (see implementation for details),
   but you can hide some reimplementing isPropertyVisibleInternal() (don't forget to call superclass' method)
   To add new properties, just define new TQ_PROPERTY in widget class definition.\n \n
@@ -236,15 +236,15 @@ class KFORMEDITOR_EXPORT WidgetInfo
   * "orientationSelectionPopup:verticalIcon" - the same for "Vertical" item.
     Set this property only for classes supporting orientations.
   * "orientationSelectionPopup:horizontalText" - sets a i18n'd text for "Horizontal" item
-    for objects of class 'ClassName', e.g. i18n("InsertQt::Horizontal Line").
+    for objects of class 'ClassName', e.g. i18n("Insert Horizontal Line").
     Set this property only for classes supporting orientations.
   * "orientationSelectionPopup:verticalText" - the same for "Vertical" item,
-    e.g. i18n("InsertQt::Vertical Line"). Set this property only for classes supporting orientations.
+    e.g. i18n("Insert Vertical Line"). Set this property only for classes supporting orientations.
   * "dontStartEditingOnInserting" - if not empty, WidgetFactory::startEditing() will not be executed upon
     widget inseting by a user.
-  * "forceShowAdvancedProperty:{propertyname}" - set it to "1" for "{propertyname}" advanced property 
-    if you want to force it to be visible even if WidgetLibrary::setAdvancedPropertiesVisible(false) 
-    has been called. For example, setting "forceShowAdvancedProperty:pixmap" to "1" 
+  * "forceShowAdvancedProperty:{propertyname}" - set it to "1" for "{propertyname}" advanced property
+    if you want to force it to be visible even if WidgetLibrary::setAdvancedPropertiesVisible(false)
+    has been called. For example, setting "forceShowAdvancedProperty:pixmap" to "1"
     unhides "pixmap" property for a given class.
 
   See StdWidgetFactory::StdWidgetFactory() for properties like
@@ -257,10 +257,10 @@ class KFORMEDITOR_EXPORT WidgetInfo
 class KFORMEDITOR_EXPORT WidgetFactory : public TQObject
 {
 	Q_OBJECT
-  TQ_OBJECT
+
 	public:
 		//! Options used in createWidget()
-		enum CreateWidgetOptions { 
+		enum CreateWidgetOptions {
 			AnyOrientation = 1, //!< any orientation hint
 			HorizontalOrientation = 2,  //!< horizontal orientation hint
 			VerticalOrientation = 4, //!< vertical orientation hint
@@ -295,12 +295,12 @@ class KFORMEDITOR_EXPORT WidgetFactory : public TQObject
 		 * \param options options for the created widget: orientation and view mode (see CreateWidgetOptions)
 		 */
 		virtual TQWidget* createWidget(const TQCString &classname, TQWidget *parent, const char *name,
-			KFormDesigner::Container *container, 
+			KFormDesigner::Container *container,
 			int options = DefaultOptions) = 0;
 
-		/*! Creates custom actions. Reimplement this if you need to add some 
+		/*! Creates custom actions. Reimplement this if you need to add some
 		 actions coming from the factory. */
-		virtual void createCustomActions(KActionCollection *col) { Q_UNUSED(col); };
+		virtual void createCustomActions(TDEActionCollection *col) { Q_UNUSED(col); };
 
 		/*! This function can be used to add custom items in widget \a w context
 		menu \a menu. */
@@ -372,14 +372,14 @@ class KFORMEDITOR_EXPORT WidgetFactory : public TQObject
 
 	protected:
 		/*! This function is called when we want to know whether the property should be visible.
-		 Implement it in the factory; don't forget to call implementation in the superclass. 
+		 Implement it in the factory; don't forget to call implementation in the superclass.
 		 Default implementation hides "caption", "icon", "sizeIncrement" and "iconText" properties. */
 		virtual bool isPropertyVisibleInternal(const TQCString &classname, TQWidget *w,
 			const TQCString &property, bool isTopLevel);
 
 		/*! Sometimes property sets should be reloaded when a given property value changed.
 		 Implement it in the factory. Default implementation always returns false. */
-		virtual bool propertySetShouldBeReloadedAfterPropertyChange(const TQCString& classname, TQWidget *w, 
+		virtual bool propertySetShouldBeReloadedAfterPropertyChange(const TQCString& classname, TQWidget *w,
 			const TQCString& property);
 
 		/*! This function creates a KLineEdit to input some text and edit a widget's contents.
@@ -497,8 +497,8 @@ class KFORMEDITOR_EXPORT WidgetFactory : public TQObject
 		 It's value is inherited from WidgetLibrary. */
 		bool m_showAdvancedProperties;
 
-		/*! Contains name of an XMLGUI file providing toolbar buttons 
-		 (and menu items in the future?) for the factory. 
+		/*! Contains name of an XMLGUI file providing toolbar buttons
+		 (and menu items in the future?) for the factory.
 		 Can be empty, e.g. for the main factory which has XMLGUI defined in the shell window itself
 		 (e.g. kexiformpartinstui.rc for Kexi Forms). This name is set in WidgetLibrary::loadFactories() */
 		TQString m_xmlGUIFileName;
