@@ -21,13 +21,13 @@
 #ifndef KEXIBROWSER_P_H
 #define KEXIBROWSER_P_H
 
-#include <klistview.h>
+#include <tdelistview.h>
 
 /*! @internal */
-class KexiBrowserListView : public KListView
+class KexiBrowserListView : public TDEListView
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 	public:
 		KexiBrowserListView(TQWidget *parent);
 		~KexiBrowserListView();
