@@ -44,12 +44,12 @@
 #include "stencilbarbutton.h"
 
 #include <unistd.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
 #include <kprinter.h>
 #include <kdebug.h>
 #include <kurl.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <assert.h>
 #include <tqdatetime.h>
 #include <sys/types.h>
@@ -68,11 +68,11 @@
 
 
 #include <kstandarddirs.h>
-#include <kpopupmenu.h>
-#include <kmenubar.h>
+#include <tdepopupmenu.h>
+#include <tdemenubar.h>
 #include <kiconloader.h>
 #include <khelpmenu.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <KoTemplateChooseDia.h>
 #include <KoFilterManager.h>
 #include <KoStoreDevice.h>
@@ -80,7 +80,7 @@
 #include <kcommand.h>
 #include <KoZoomHandler.h>
 #include <KoApplication.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <KoCommandHistory.h>
 #include <KoXmlWriter.h>
 #include <KoGenStyles.h>
@@ -552,7 +552,7 @@ bool KivioDoc::loadXML( TQIODevice *, const TQDomDocument& doc )
 
 bool KivioDoc::loadStencilSpawnerSet(const TQString &id, bool hidden)
 {
-  KStandardDirs *dirs = KGlobal::dirs();
+  TDEStandardDirs *dirs = TDEGlobal::dirs();
   TQStringList dirList = dirs->findDirs("data", "kivio/stencils");
   TQString rootDir;
 
