@@ -49,7 +49,7 @@ class TQPainter;
 class KTextEdit;
 class KPrTextObject;
 class KPrObject;
-class KPopupMenu;
+class TDEPopupMenu;
 class TQResizeEvent;
 class TQPaintEvent;
 class TQDragEnterEvent;
@@ -82,7 +82,7 @@ class KPrPageEffects;
 class KPrCanvas : public TQWidget
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
 
@@ -791,7 +791,7 @@ private:
     static const int KEY_SNAP_DISTANCE;
     // variables
     /// Popup menu used in presentation mode.
-    KPopupMenu *m_presMenu;
+    TDEPopupMenu *m_presMenu;
     bool showingLastSlide;
     bool mousePressed;
     bool drawContour;
