@@ -39,14 +39,14 @@
 #include <tqtooltip.h>
 #include <tqwhatsthis.h>
 
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 #include <kbuttonbox.h>
 #include <knuminput.h>
 #include <kurlrequester.h>
 #include <kurl.h>
 #include <kstandarddirs.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 
 KPrEffectDia::KPrEffectDia( TQWidget* parent, const char* name, const TQPtrList<KPrObject>& _objs,
                       KPrView *_view )
@@ -185,7 +185,7 @@ KPrEffectDia::KPrEffectDia( TQWidget* parent, const char* name, const TQPtrList<
     connect( buttonTestPlaySoundEffect1, TQT_SIGNAL( clicked() ), this, TQT_SLOT( playSound1() ) );
 
     buttonTestStopSoundEffect1 = new TQPushButton( grp1 );
-    buttonTestStopSoundEffect1->setIconSet( SmallIconSet("player_stop") );
+    buttonTestStopSoundEffect1->setIconSet( SmallIconSet("media-playback-stop") );
     TQToolTip::add( buttonTestStopSoundEffect1, i18n("Stop") );
     upperRow->addWidget( buttonTestStopSoundEffect1, 6, 3 );
 
@@ -289,7 +289,7 @@ KPrEffectDia::KPrEffectDia( TQWidget* parent, const char* name, const TQPtrList<
     connect( buttonTestPlaySoundEffect2, TQT_SIGNAL( clicked() ), this, TQT_SLOT( playSound2() ) );
 
     buttonTestStopSoundEffect2 = new TQPushButton( grp2 );
-    buttonTestStopSoundEffect2->setIconSet( SmallIconSet("player_stop") );
+    buttonTestStopSoundEffect2->setIconSet( SmallIconSet("media-playback-stop") );
     TQToolTip::add( buttonTestStopSoundEffect2, i18n("Stop") );
     lowerRow->addWidget( buttonTestStopSoundEffect2, 5, 3 );
 
@@ -427,7 +427,7 @@ void KPrEffectDia::slotRequesterClicked( KURLRequester *requester )
     requester->fileDialog()->setFilter( filter );
 
     // find the first "sound"-resource that contains files
-    TQStringList soundDirs = KGlobal::dirs()->resourceDirs( "sound" );
+    TQStringList soundDirs = TDEGlobal::dirs()->resourceDirs( "sound" );
     if ( !soundDirs.isEmpty() ) {
         KURL soundURL;
         TQDir dir;
