@@ -26,7 +26,7 @@
 #include "KPrCanvas.h"
 
 #include <KoZoomHandler.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 #include <tqpainter.h>
 #include <tqpaintdevice.h>
