@@ -33,7 +33,7 @@
 #include <tqbuffer.h>
 #include <tqregexp.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <KoOasisContext.h>
 #include "KoOasisStyles.h"
 
@@ -50,36 +50,36 @@
 #include <KoDom.h>
 #include <kdebug.h>
 
-const TQString &KPrObject::tagORIG=KGlobal::staticQString("ORIG");
-const TQString &KPrObject::attrX=KGlobal::staticQString("x");
-const TQString &KPrObject::attrY=KGlobal::staticQString("y");
-const TQString &KPrObject::tagSIZE=KGlobal::staticQString("SIZE");
-const TQString &KPrObject::attrWidth=KGlobal::staticQString("width");
-const TQString &KPrObject::attrHeight=KGlobal::staticQString("height");
-const TQString &KPrObject::tagSHADOW=KGlobal::staticQString("SHADOW");
-const TQString &KPrObject::attrDistance=KGlobal::staticQString("distance");
-const TQString &KPrObject::attrDirection=KGlobal::staticQString("direction");
-const TQString &KPrObject::attrColor=KGlobal::staticQString("color");
-const TQString &KPrObject::tagEFFECTS=KGlobal::staticQString("EFFECTS");
-const TQString &KPrObject::attrEffect=KGlobal::staticQString("effect");
-const TQString &KPrObject::attrEffect2=KGlobal::staticQString("effect2");
-const TQString &KPrObject::tagPRESNUM=KGlobal::staticQString("PRESNUM");
-const TQString &KPrObject::tagANGLE=KGlobal::staticQString("ANGLE");
-const TQString &KPrObject::tagDISAPPEAR=KGlobal::staticQString("DISAPPEAR");
-const TQString &KPrObject::attrDoit=KGlobal::staticQString("doit");
-const TQString &KPrObject::attrNum=KGlobal::staticQString("num");
-const TQString &KPrObject::tagFILLTYPE=KGlobal::staticQString("FILLTYPE");
-const TQString &KPrObject::tagGRADIENT=KGlobal::staticQString("GRADIENT");
-const TQString &KPrObject::tagPEN=KGlobal::staticQString("PEN");
-const TQString &KPrObject::tagBRUSH=KGlobal::staticQString("BRUSH");
-const TQString &KPrObject::attrValue=KGlobal::staticQString("value");
-const TQString &KPrObject::attrC1=KGlobal::staticQString("color1");
-const TQString &KPrObject::attrC2=KGlobal::staticQString("color2");
-const TQString &KPrObject::attrType=KGlobal::staticQString("type");
-const TQString &KPrObject::attrUnbalanced=KGlobal::staticQString("unbalanced");
-const TQString &KPrObject::attrXFactor=KGlobal::staticQString("xfactor");
-const TQString &KPrObject::attrYFactor=KGlobal::staticQString("yfactor");
-const TQString &KPrObject::attrStyle=KGlobal::staticQString("style");
+const TQString &KPrObject::tagORIG=TDEGlobal::staticQString("ORIG");
+const TQString &KPrObject::attrX=TDEGlobal::staticQString("x");
+const TQString &KPrObject::attrY=TDEGlobal::staticQString("y");
+const TQString &KPrObject::tagSIZE=TDEGlobal::staticQString("SIZE");
+const TQString &KPrObject::attrWidth=TDEGlobal::staticQString("width");
+const TQString &KPrObject::attrHeight=TDEGlobal::staticQString("height");
+const TQString &KPrObject::tagSHADOW=TDEGlobal::staticQString("SHADOW");
+const TQString &KPrObject::attrDistance=TDEGlobal::staticQString("distance");
+const TQString &KPrObject::attrDirection=TDEGlobal::staticQString("direction");
+const TQString &KPrObject::attrColor=TDEGlobal::staticQString("color");
+const TQString &KPrObject::tagEFFECTS=TDEGlobal::staticQString("EFFECTS");
+const TQString &KPrObject::attrEffect=TDEGlobal::staticQString("effect");
+const TQString &KPrObject::attrEffect2=TDEGlobal::staticQString("effect2");
+const TQString &KPrObject::tagPRESNUM=TDEGlobal::staticQString("PRESNUM");
+const TQString &KPrObject::tagANGLE=TDEGlobal::staticQString("ANGLE");
+const TQString &KPrObject::tagDISAPPEAR=TDEGlobal::staticQString("DISAPPEAR");
+const TQString &KPrObject::attrDoit=TDEGlobal::staticQString("doit");
+const TQString &KPrObject::attrNum=TDEGlobal::staticQString("num");
+const TQString &KPrObject::tagFILLTYPE=TDEGlobal::staticQString("FILLTYPE");
+const TQString &KPrObject::tagGRADIENT=TDEGlobal::staticQString("GRADIENT");
+const TQString &KPrObject::tagPEN=TDEGlobal::staticQString("PEN");
+const TQString &KPrObject::tagBRUSH=TDEGlobal::staticQString("BRUSH");
+const TQString &KPrObject::attrValue=TDEGlobal::staticQString("value");
+const TQString &KPrObject::attrC1=TDEGlobal::staticQString("color1");
+const TQString &KPrObject::attrC2=TDEGlobal::staticQString("color2");
+const TQString &KPrObject::attrType=TDEGlobal::staticQString("type");
+const TQString &KPrObject::attrUnbalanced=TDEGlobal::staticQString("unbalanced");
+const TQString &KPrObject::attrXFactor=TDEGlobal::staticQString("xfactor");
+const TQString &KPrObject::attrYFactor=TDEGlobal::staticQString("yfactor");
+const TQString &KPrObject::attrStyle=TDEGlobal::staticQString("style");
 
 KPrStartEndLine::KPrStartEndLine( LineEnd _start, LineEnd _end )
     : lineBegin( _start ), lineEnd( _end )
