@@ -27,7 +27,7 @@
 #include <tqwidget.h>
 #include <tqwmatrix.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
 #include <krandomsequence.h>
 
