@@ -30,7 +30,7 @@
 #include <kstandarddirs.h>
 #include <unistd.h>
 #include <sys/types.h>
-#include <ktempfile.h>
+#include <tdetempfile.h>
 
 #include <tqfile.h>
 #include <tqtextstream.h>
@@ -54,24 +54,24 @@
 #include <tqcheckbox.h>
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kcolorbutton.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
 #include <kbuttonbox.h>
 #include <ksimpleconfig.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kprogress.h>
-#include <kglobal.h>
-#include <kglobalsettings.h>
+#include <tdeglobal.h>
+#include <tdeglobalsettings.h>
 #include <kcharsets.h>
 #include <kurlrequester.h>
 #include <klineedit.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <knuminput.h>
 #include <kcombobox.h>
 #include <kurl.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 #include <kdialog.h>
 
 #include "KoDocumentInfo.h"
@@ -269,14 +269,14 @@ void KPrWebPresentation::initCreation( KProgress *progressBar )
     TQString cmd;
     int p;
     KURL str(  path + "/html"  );
-    KIO::NetAccess::mkdir( str,( TQWidget* )0L  );
+    TDEIO::NetAccess::mkdir( str,( TQWidget* )0L  );
 
     p = progressBar->progress();
     progressBar->setProgress( ++p );
     kapp->processEvents();
 
     str = path + "/pics";
-    KIO::NetAccess::mkdir( str,( TQWidget* )0L );
+    TDEIO::NetAccess::mkdir( str,( TQWidget* )0L );
 
     p = progressBar->progress();
     progressBar->setProgress( ++p );
@@ -293,7 +293,7 @@ void KPrWebPresentation::initCreation( KProgress *progressBar )
         srcurl.setPath( locate( "slideshow", filename, KPrFactory::global() ) );
         desturl = path;
         desturl.addPath( "/pics/" + filename );
-        KIO::NetAccess::file_copy( srcurl, desturl, -1, true /*overwrite*/);
+        TDEIO::NetAccess::file_copy( srcurl, desturl, -1, true /*overwrite*/);
         p = progressBar->progress();
         progressBar->setProgress( ++p );
         kapp->processEvents();
@@ -315,7 +315,7 @@ void KPrWebPresentation::createSlidesPictures( KProgress *progressBar )
         KTempFile tmp;
         pix.save( tmp.name(), "PNG" );
 
-        KIO::NetAccess::file_move( tmp.name(), filename, -1, true /*overwrite*/);
+        TDEIO::NetAccess::file_move( tmp.name(), filename, -1, true /*overwrite*/);
 
         p = progressBar->progress();
         progressBar->setProgress( ++p );
@@ -387,7 +387,7 @@ void KPrWebPresentation::writeStartOfHeader(TQTextStream& streamOut, TQTextCodec
 
 void KPrWebPresentation::createSlidesHTML( KProgress *progressBar )
 {
-    TQTextCodec *codec = KGlobal::charsets()->codecForName( m_encoding );
+    TQTextCodec *codec = TDEGlobal::charsets()->codecForName( m_encoding );
 
     const TQString brtag ( "<br" + TQString(isXML()?" /":"") + ">" );
 
@@ -511,7 +511,7 @@ void KPrWebPresentation::createSlidesHTML( KProgress *progressBar )
             else
                 htmlAuthor=TQString("<a href=\"mailto:%1\">%2</a>").arg( escapeHtmlText( codec, email )).arg( escapeHtmlText( codec, author ));
             streamOut << EscapeEncodingOnly ( codec, i18n( "Created on %1 by <i>%2</i> with <a href=\"http://www.koffice.org/kpresenter\">KPresenter</a>" )
-                                          .arg( KGlobal::locale()->formatDate ( TQDate::currentDate() ) ).arg( htmlAuthor ) );
+                                          .arg( TDEGlobal::locale()->formatDate ( TQDate::currentDate() ) ).arg( htmlAuthor ) );
 
             streamOut << "    </center><hr noshade=\"noshade\"" << ( isXML() ?" /":"") << ">\n";
         }
@@ -520,7 +520,7 @@ void KPrWebPresentation::createSlidesHTML( KProgress *progressBar )
 
         file.close();
 
-        KIO::NetAccess::file_move( tmp.name(), dest, -1, true /*overwrite*/);
+        TDEIO::NetAccess::file_move( tmp.name(), dest, -1, true /*overwrite*/);
 
         int p = progressBar->progress();
         progressBar->setProgress( ++p );
@@ -530,7 +530,7 @@ void KPrWebPresentation::createSlidesHTML( KProgress *progressBar )
 
 void KPrWebPresentation::createMainPage( KProgress *progressBar )
 {
-    TQTextCodec *codec = KGlobal::charsets()->codecForName( m_encoding );
+    TQTextCodec *codec = TDEGlobal::charsets()->codecForName( m_encoding );
     KTempFile tmp;
     TQString dest = TQString( "%1/index.html" ).arg( path );
     TQFile file( tmp.name() );
@@ -562,12 +562,12 @@ void KPrWebPresentation::createMainPage( KProgress *progressBar )
     TQString htmlAuthor = email.isEmpty() ? escapeHtmlText( codec, author ) :
                          TQString("<a href=\"mailto:%1\">%2</a>").arg( escapeHtmlText( codec, email )).arg( escapeHtmlText( codec, author ));
     streamOut << EscapeEncodingOnly ( codec, i18n( "Created on %1 by <i>%2</i> with <a href=\"http://www.koffice.org/kpresenter\">KPresenter</a>" )
-                                      .arg( KGlobal::locale()->formatDate ( TQDate::currentDate() ) ).arg( htmlAuthor ) );
+                                      .arg( TDEGlobal::locale()->formatDate ( TQDate::currentDate() ) ).arg( htmlAuthor ) );
 
     streamOut << "</body>\n</html>\n";
     file.close();
 
-    KIO::NetAccess::file_move( tmp.name(), dest, -1, true /*overwrite*/);
+    TDEIO::NetAccess::file_move( tmp.name(), dest, -1, true /*overwrite*/);
 
 
     progressBar->setProgress( progressBar->totalSteps() );
@@ -605,7 +605,7 @@ void KPrWebPresentation::init()
     textColor = TQt::black;
     titleColor = TQt::red;
 
-    path = KGlobalSettings::documentPath() + "www";
+    path = TDEGlobalSettings::documentPath() + "www";
 
     zoom = 100;
 
@@ -801,13 +801,13 @@ void KPrWebPresentationWizard::setupPage2()
     layout->addWidget( encoding, 3, 1 );
 
     // Fill encoding combo
-    // Stolen from kdelibs/kate/part/katedialogs.cpp
-    TQStringList encodings(KGlobal::charsets()->descriptiveEncodingNames());
+    // Stolen from tdelibs/kate/part/katedialogs.cpp
+    TQStringList encodings(TDEGlobal::charsets()->descriptiveEncodingNames());
     int idx = 0;
     for (uint i = 0; i < encodings.count(); i++)
     {
       bool found = false;
-      TQTextCodec *codecForEnc = KGlobal::charsets()->codecForName(KGlobal::charsets()->encodingForName(encodings[i]), found);
+      TQTextCodec *codecForEnc = TDEGlobal::charsets()->codecForName(TDEGlobal::charsets()->encodingForName(encodings[i]), found);
       if (found)
       {
         encoding->insertItem(encodings[i]);
@@ -932,7 +932,7 @@ void KPrWebPresentationWizard::setupPage4()
     connect( slideTitle, TQT_SIGNAL( textChanged( const TQString & ) ), this,
              TQT_SLOT( slideTitleChanged( const TQString & ) ) );
 
-    slideTitles = new KListView( canvas );
+    slideTitles = new TDEListView( canvas );
     layout->addMultiCellWidget( slideTitles, 2, 2, 0, 1 );
     slideTitles->addColumn( i18n( "No." ) );
     slideTitles->addColumn( i18n( "Slide Title" ) );
@@ -945,7 +945,7 @@ void KPrWebPresentationWizard::setupPage4()
 
     TQValueList<KPrWebPresentation::SlideInfo> infos = webPres.getSlideInfos();
     for ( int i = infos.count() - 1; i >= 0; --i ) {
-        KListViewItem *item = new KListViewItem( slideTitles );
+        TDEListViewItem *item = new TDEListViewItem( slideTitles );
         item->setText( 0, TQString::number( i + 1 ) );
         //kdDebug(33001) << "KPrWebPresentationWizard::setupPage3 " << infos[ i ].slideTitle << endl;
         item->setText( 1, infos[ i ].slideTitle );
@@ -1060,7 +1060,7 @@ void KPrWebPresentationWizard::finish()
     webPres.setLoopSlides( loopSlides->isChecked() );
     webPres.setXML( doctype->currentItem() != 0 );
     bool found = false;
-    TQTextCodec *codecForEnc = KGlobal::charsets()->codecForName(KGlobal::charsets()->encodingForName(encoding->currentText()), found);
+    TQTextCodec *codecForEnc = TDEGlobal::charsets()->codecForName(TDEGlobal::charsets()->encodingForName(encoding->currentText()), found);
     if ( found )
     {
         webPres.setEncoding( codecForEnc->name() );
@@ -1077,7 +1077,7 @@ void KPrWebPresentationWizard::pageChanged()
         TQString pathname = path->lineEdit()->text();
 
         // path doesn't exist. ask user if it should be created.
-        if ( !KIO::NetAccess::exists( pathname, true/*write*/,this ) )
+        if ( !TDEIO::NetAccess::exists( pathname, true/*write*/,this ) )
         {
             TQString msg = i18n( "<qt>The directory <b>%1</b> does not exist.<br>"
                                 "Do you want create it?</qt>" );
@@ -1085,7 +1085,7 @@ void KPrWebPresentationWizard::pageChanged()
                                             i18n( "Directory Not Found" ) )
                 == KMessageBox::Yes)
             {
-                bool ok = KIO::NetAccess::mkdir( pathname, this );
+                bool ok = TDEIO::NetAccess::mkdir( pathname, this );
                 if( !ok )
                 {
                     KMessageBox::sorry( this,
