@@ -28,11 +28,11 @@
 #include <KoStore.h>
 #include <KoStoreDevice.h>
 
-#include <kparts/partmanager.h>
+#include <tdeparts/partmanager.h>
 
 #include <kmimetype.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kdebug.h>
 
 #include <tqapplication.h>
